@@ -1,7 +1,7 @@
 """This is the 'nester.py' module, and it providesone function called print_lol()
     which prints lists that may or may not include nested lists."""
 
-def print_lol(the_list, level=0):
+def print_lol(the_list, indent=False, level=0):
     """This function takes a positional argument called 'the_list', which
         is any Python list (of possibly,nested lists). Each data item in the
         provided list is (recursively) printed to the screem on its own line.
@@ -9,8 +9,9 @@ def print_lol(the_list, level=0):
 
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item, level+1)
+            print_lol(each_item, ident, level+1)
         else:
-            for tab_stop in range(level):
-                print("\t", end='')
+            if indent:
+                for tab_stop in range(level):
+                    print("\t", end='')
             print(each_item)
